@@ -54,6 +54,32 @@ def dsfr_favicon() -> None:
     return None
 
 
+@register.inclusion_tag("dsfr/form_snippet.html", takes_context=True)
+def dsfr_form(context) -> dict:
+    """
+    Returns the HTML for a form snippet
+
+    **Tag name**::
+        dsfr_form
+    **Usage**::
+        {% dsfr_form %}
+    """
+    return context
+
+
+@register.inclusion_tag("dsfr/form_field_snippets/field_snippet.html")
+def dsfr_form_field(field) -> dict:
+    """
+    Returns the HTML for a form field snippet
+
+    **Tag name**::
+        dsfr_form_field
+    **Usage**::
+        {% dsfr_form_field field %}
+    """
+    return {"field": field}
+
+
 @register.inclusion_tag("dsfr/theme_modale.html")
 def dsfr_theme_modale() -> None:
     """
@@ -101,7 +127,7 @@ def dsfr_accordion(*args, **kwargs) -> dict:
 @register.inclusion_tag("dsfr/accordion_group.html")
 def dsfr_accordion_group(items: list) -> dict:
     """
-    Returns a group of accordion items. Takes a list of dicts as parameters (see the accordeon
+    Returns a group of accordion items. Takes a list of dicts as parameters (see the accordion
     tag for the structure of these dicts.)
 
     **Tag name**::
@@ -157,6 +183,52 @@ def dsfr_alert(*args, **kwargs) -> dict:
     return {"self": tag_data}
 
 
+@register.inclusion_tag("dsfr/badge.html")
+def dsfr_badge(*args, **kwargs) -> dict:
+    """
+    Returns a badge item. Takes a dict as parameter, with the following structure:
+
+    data_dict = {
+        "label": "Label of the button item",
+        "extra_classes": "(Optional) string with names of extra classes."
+    }
+
+    All of the keys of the dict can be passed directly as named parameters of the tag.
+
+    Relevant extra_classes
+    - "fr-badge--sm" : small-sized badge
+    - "fr-badge--green-menthe" other color codes: change the color of the badge
+    - "fr-badge--success" (or error/info/warning/new): system badges
+    - "fr-badge--no-icon": removes the icon on system badges
+
+    **Tag name**::
+        dsfr_badge
+    **Usage**::
+        {% dsfr_badge data_dict %}
+    """
+    allowed_keys = [
+        "label",
+        "extra_classes",
+    ]
+    tag_data = parse_tag_args(args, kwargs, allowed_keys)
+
+    return {"self": tag_data}
+
+
+@register.inclusion_tag("dsfr/badge_group.html")
+def dsfr_badge_group(items: list) -> dict:
+    """
+    Returns a group of badge items. Takes a list of dicts as parameters (see the badge
+    tag for the structure of these dicts.)
+
+    **Tag name**::
+        dsfr_badge_group
+    **Usage**::
+        {% dsfr_badge_group data_list %}
+    """
+    return {"self": {"items": items}}
+
+
 @register.inclusion_tag("dsfr/breadcrumb.html", takes_context=True)
 def dsfr_breadcrumb(context: Context, tag_data: dict = {}) -> dict:
     """
@@ -216,10 +288,6 @@ def dsfr_button(*args, **kwargs) -> dict:
     ]
     tag_data = parse_tag_args(args, kwargs, allowed_keys)
 
-    for k in kwargs:
-        if k in allowed_keys:
-            tag_data[k] = kwargs[k]
-
     if "is_disabled" not in tag_data:
         tag_data["is_disabled"] = False
     return {"self": tag_data}
@@ -266,31 +334,72 @@ def dsfr_card(*args, **kwargs) -> dict:
     Returns a card item. Takes a dict as parameter, with the following structure:
 
     data_dict = {
-        "detail": "Appears before the title of the card item",
         "title": "Title of the card item",
+        "heading_tag": "(Optional) Heading tag for the title (h2, etc. Default: p)"
         "description": "Text of the card item",
-        "image": "(Optional) url of the image",
+        "image_url": "(Optional) url of the image",
+        "image_alt": "(Optional) alt text of the image",
+        "media_badges": (Optional) list of badges for the media area (similar to a badge_group tag)
         "new_tab": "(Optional) if True, forces links to open in a new tab",
+        "enlarge_link": (Optional) boolean. If true (default), the link covers the whole card",
         "extra_classes": "(Optional) string with names of extra classes",
+        "top_detail": "(Optional) dict with a top detail content and optional tags or badges",
+        "bottom_detail": "(Optional) a detail string and optional icon",
+        "call_to_action": "(Optional) a list of buttons or links at the bottom of the card,
     }
 
     All of the keys of the dict can be passed directly as named parameters of the tag.
 
+    Relevant extra classes:
+    - fr-card--horizontal: makes the card horizontal
+    - fr-card--horizontal-tier: allows a 33% ratio instead of the 40% default
+    - fr-card--horizontal-half: allows a 50% ratio instead of the 40% default
+
+    Format of the top_detail dict (every field is optional):
+    top_detail = {
+        "detail": {
+            "text": "the detail text",
+            "icon_class": "(Optional) an icon class (eg, fr-icon-warning-fill)"
+        },
+        "tags": "a list of tag items (mutually exclusive with badges)",
+        "badges": "a list of badge items (mutually exclusive with tags)"
+    }
+
+    Format of the bottom_detail dict :
+    bottom_detail = {
+        "text": "the detail text",
+        "icon_class": "(Optional) an icon class (eg, fr-icon-warning-fill)"
+    },
+
+
     **Tag name**::
         dsfr_card
     **Usage**::
         {% dsfr_card data_dict %}
     """
     allowed_keys = [
-        "detail",
         "title",
+        "heading_tag",
         "description",
         "image_url",
+        "image_alt",
+        "media_badges",
         "new_tab",
+        "enlarge_link",
         "extra_classes",
+        "top_detail",
+        "bottom_detail",
+        "call_to_action",
     ]
     tag_data = parse_tag_args(args, kwargs, allowed_keys)
 
+    if "enlarge_link" not in tag_data:
+        tag_data["enlarge_link"] = True
+
+    if "call_to_action" in tag_data:
+        # Forcing the enlarge_link to false if there is a CTA
+        tag_data["enlarge_link"] = False
+
     return {"self": tag_data}
 
 
@@ -510,6 +619,7 @@ def dsfr_sidemenu(context: Context, *args, **kwargs) -> dict:
     data_dict = {
         "title": "The title of the main menu",
         "items": "a list of similarly structured dictionaries (see below)",
+        "heading_tag": "(Optional) Heading tag for the accordion title (h2, etc. Default: div)"
         "extra_classes": "(Optional) string with names of extra classes",
     }
 
@@ -530,7 +640,7 @@ def dsfr_sidemenu(context: Context, *args, **kwargs) -> dict:
         {% dsfr_sidemenu data_dict %}
     """
 
-    allowed_keys = ["label", "items", "extra_classes"]
+    allowed_keys = ["label", "items", "heading_tag", "extra_classes"]
     tag_data = parse_tag_args(args, kwargs, allowed_keys)
 
     active_path = context["request"].path
@@ -615,12 +725,14 @@ def dsfr_tag(*args, **kwargs) -> dict:
         "label": "Label of the tag",
         "link": "(Optional) link of the tag",
         "onclick": "(Optional) action that happens when the tag is clicked on",
+        "is_selectable": "(Optional) boolean that marks the tag as selectable",
+        "is_dismissable": "(Optional) boolean that marks the tag as dismissable",
         "extra_classes: (Optional) string with names of extra classes"
     }
 
     Relevant extra_classes:
     - fr-tag--sm: for a small tag
-    - icon classes: an icon for the tag, along with a positional class (eg, fr-fi-arrow-right-line fr-tag--icon-left)
+    - icon classes: an icon for the tag, along with a positional class (eg, fr-icon-arrow-right-line fr-tag--icon-left)
 
     All of the keys of the dict can be passed directly as named parameters of the tag.
 
@@ -630,7 +742,14 @@ def dsfr_tag(*args, **kwargs) -> dict:
         {% dsfr_highlight data_dict %}
     """
 
-    allowed_keys = ["label", "link", "onclick", "extra_classes"]
+    allowed_keys = [
+        "label",
+        "link",
+        "onclick",
+        "extra_classes",
+        "is_selectable",
+        "is_dismissable",
+    ]
     tag_data = parse_tag_args(args, kwargs, allowed_keys)
 
     return {"self": tag_data}
